@@ -316,7 +316,10 @@ impl Visit for SpanVisualizer<'_> {
     mtd!(Tokens, visit_tokens);
     mtd!(Unit, visit_unit);
     mtd!(UnitValue, visit_unit_value);
+    mtd!(Url, visit_url);
     mtd!(UrlValue, visit_url_value);
+    mtd!(UrlValueRaw, visit_url_value_raw);
+    mtd!(UrlModifier, visit_url_modifier);
     mtd!(Value, visit_value);
 
     mtd!(CharsetRule, visit_charset_rule);
